@@ -10,11 +10,14 @@ dir_ = os.path.dirname(os.path.realpath(__file__))
 def exec_module(path):
     """Executes the Python file at `path` and returns it as the module"""
 
+    # We don't care about MSYSTEM in the doc build, just unset to prevent the
+    # assert in const.py
+    os.environ.pop("MSYSTEM", None)
     globals_ = {}
     if sys.version_info[0] == 2:
         execfile(path, globals_)
     else:
-        with open(path) as h:
+        with open(path, encoding="utf-8") as h:
             exec(h.read(), globals_)
     module = types.ModuleType("")
     module.__dict__.update(globals_)
@@ -31,15 +34,7 @@ project = 'Quod Libet'
 copyright = u""
 exclude_patterns = ['_build', '_build_all', 'README.rst', '**/README.rst']
 html_theme = "sphinx_rtd_theme"
-
-if const.BRANCH_NAME != "master":
-    version = ".".join(const.VERSION.rsplit(".")[:2])
-    release = const.VERSION
-    if release.endswith(".-1"):
-        release = release[:-3]
-    html_title = "%s (%s)" % (project, version)
-else:
-    html_title = project
+html_title = project
 
 extlinks = {
     'bug': ('https://github.com/quodlibet/quodlibet/issues/%s', '#'),
@@ -50,7 +45,7 @@ extlinks = {
 linkcheck_anchors = True
 linkcheck_workers = 20
 linkcheck_ignore = [
-    ".*groups\.google\.com/.*",
+    r".*groups\.google\.com/.*",
     r".*keyserver\.ubuntu\.com.*"
 ]
 
@@ -71,13 +66,3 @@ html_theme_options = {
 
 html_favicon = "favicon/favicon.ico"
 html_show_copyright = False
-
-# on a stable branch which isn't a release
-if const.BRANCH_NAME != "master":
-    rst_prolog = """
-
-.. note::
-    There exists a newer version of this page and the content below may be
-    outdated. See %s for the latest documentation.
-
-""" % (const.DOCS_LATEST)
