@@ -1,15 +1,15 @@
 # -*- coding: utf-8 -*-
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman, Iñigo Serna
 #           2012 Christoph Reiter
+#           2016,18 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
-import os
-
-import quodlibet
 from quodlibet import util
+from quodlibet.compat import listfilter
 from quodlibet.util.importhelper import load_dir_modules
 
 from ._base import Browser
@@ -22,7 +22,7 @@ default = None
 def init():
     """Import all browsers from this package and from the user directory.
 
-    After this is called the global `browers` list will contain all
+    After this is called the global `browsers` list will contain all
     classes sorted by priority.
 
     Can be called multiple times.
@@ -34,27 +34,21 @@ def init():
     if browsers:
         return
 
-    this_dir = os.path.dirname(__file__)
+    this_dir = util.get_module_dir()
     load_pyc = util.is_windows() or util.is_osx()
     modules = load_dir_modules(this_dir,
                                package=__package__,
                                load_compiled=load_pyc)
 
-    user_dir = os.path.join(quodlibet.get_user_dir(), "browsers")
-    if os.path.isdir(user_dir):
-        modules += load_dir_modules(user_dir,
-                                    package="quodlibet.fake.browsers",
-                                    load_compiled=load_pyc)
-
     for browser in modules:
         try:
             browsers.extend(browser.browsers)
         except AttributeError:
-            print_w("%r doesn't contain any browsers." % browser.__name__)
+            util.print_w("%r doesn't contain any browsers." % browser.__name__)
 
     def is_browser(Kind):
         return isinstance(Kind, type) and issubclass(Kind, Browser)
-    browsers = filter(is_browser, browsers)
+    browsers = listfilter(is_browser, browsers)
 
     if not browsers:
         raise SystemExit("No browsers found!")
@@ -101,4 +95,5 @@ def index(name):
         if name in keys:
             return j
 
-    raise ValueError("%r not found" % name)
+    raise ValueError("%r not found. Try: %s"
+                     % (name, [b.keys for b in browsers]))
