@@ -1,25 +1,42 @@
 # -*- coding: utf-8 -*-
 # Copyright 2004-2008 Joe Wreschnig
-#           2009-2013 Nick Boultbee
+#           2009-2017 Nick Boultbee
 #           2011-2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import shutil
 
+from quodlibet.util import enum
 from . import const
 from quodlibet.util.config import Config, Error
+from quodlibet.util import print_d, print_w
+from quodlibet.util import is_osx, is_windows
+from quodlibet.compat import PY2, iteritems, text_type
 
 # Some plugins can be enabled on first install
 AUTO_ENABLED_PLUGINS = ["Shuffle Playlist", "Remove Playlist Duplicates"]
 
+
+def _config_text(text):
+    # raw config values are utf-8 encoded on PY2, while they are unicode
+    # with surrogates on PY2. this makes initing the defaults work
+
+    assert isinstance(text, text_type)
+    if PY2:
+        return text.encode("utf-8")
+    return text
+
+
 # this defines the initial and default values
 INITIAL = {
     # User-defined tag name -> human name mappings
     "header_maps": {
     },
+
     "player": {
         "time_remaining": "false",
         "replaygain": "on",
@@ -27,7 +44,10 @@ INITIAL = {
         "pre_amp_gain": "0.0",
         "backend": "gstbe",
         "gst_pipeline": "",
-        "gst_buffer": "1.5", # stream buffer duration in seconds
+
+        # stream buffer duration in seconds
+        "gst_buffer": "3",
+
         "gst_device": "",
         "gst_disable_gapless": "false",
     },
@@ -35,46 +55,116 @@ INITIAL = {
         "exclude": "",
         "refresh_on_start": "true",
     },
+
     # State about the player, to restore on startup
     "memory": {
-        "song": "", # filename of last song
-        "seek": "0", # last song position, in milliseconds
-        "volume": "1.0", # internal volume, [0.0, 1.0]
-        "browser": "PanedBrowser", # browser name
-        "songlist": "true", # on or off
-        "queue": "false", # on or off
-        "shufflequeue": "false", # on or off
-        "sortby": "0album", # <reversed?>tagname, song list sort
-        "order": "inorder",
-        "order_shuffle": "shuffle",
+
+        # filename of last song
+        "song": "",
+
+        # last song position, in milliseconds
+        "seek": "0",
+
+        # internal volume, [0.0, 1.0]
+        "volume": "1.0",
+
+        # browser name
+        "browser": "PanedBrowser",
+
+        "queue": "false",
+        "queue_expanded": "false",
+        "shufflequeue": "false",
+        "queue_stop_once_empty": "false",
+
+        # <reversed?>tagname, song list sort
+        "sortby": "0album",
+
+        # Repeat on or off
+        "repeat": "false",
+
+        # The Repeat (Order) to use
+        "repeat_mode": "repeat_song",
+
+        # Shuffle on or off
         "shuffle": "false",
-        "plugin_selection": "", # selected plugin in manager
-        "column_widths": "", # column widths in c1,w1,c2,w2... format
+
+        # The Shuffle (Order) to use
+        "shuffle_mode": "random",
+
+        # selected plugin in manager
+        "plugin_selection": "",
+
+        # column widths in c1,w1,c2,w2... format
+        "column_widths": "",
+
         "column_expands": "",
     },
+
     "browsers": {
-        "query_text": "", # none/search bar text
+
+        # search bar text
+        "query_text": "",
+
         # panes in paned browser
         "panes":
-            "~people	<~year|[b][i]<~year>[/i][/b] - ><album>",
-        "pane_selection": "", # selected pane values
-        "pane_wide_mode": "0", # browser orientation
-        "background": "", # "global" filter for SearchBar
-        "albums": "", # album list
-        "album_sort": "0", # album sorting mode, default is title
-        "album_covers": "1", # album cover display, on/off
-        "album_substrings": "1", # include substrings in inline search
+            "~people\t<~year|[b][i]<~year>[/i][/b] - ><album>",
+
+        # selected pane values
+        "pane_selection": "",
+
+        # browser orientation
+        "pane_wide_mode": "0",
+
+        # equal pane width in paned browser
+        "equal_pane_width": "true",
+
+        # "global" filter for SearchBar
+        "background": "",
+
+        # album list
+        "albums": "",
+
+        # album sorting mode, default is title
+        "album_sort": "0",
+
+        # album cover display, on/off
+        "album_covers": "1",
+
+        # include substrings in inline search
+        "album_substrings": "1",
+
+        # Collections browser: tag to collect, merge or not (0 = no)
         "collection_headers": "~people 0",
-        "radio": "", # radio filter selection
-        "rating_click": "true", # click to rate song, on/off
-        "rating_hotkeys": "true", # press number keys to rate song on/off
-        "rating_confirm_multiple": "false", # confirm rating multiple songs
-        "cover_size": "-1", # max cover height/width, <= 0 is default
-        "search_limit": "false", # Show the limit widgets for SearchBar
+
+        # radio filter selection
+        "radio": "",
+
+        # click to rate song, on/off
+        "rating_click": "true",
+
+        # confirm rating multiple songs
+        "rating_confirm_multiple": "false",
+
+        # max cover height/width, <= 0 is default
+        "cover_size": "-1",
+
+        # Show the limit widgets for SearchBar
+        "search_limit": "false",
+
+        # show text in covergrid view
+        "album_text": "1",
+
+        # Cover magnifcation factor in covergrid view
+        "covergrid_magnification": "3.0",
+
+        # show "all albums" in covergrid view
+        "covergrid_all": "0",
     },
+
     # Kind of a dumping ground right now, should probably be
     # cleaned out later.
     "settings": {
+
         # scan directories, :-separated
         "scan": "",
 
@@ -91,20 +181,13 @@ INITIAL = {
         "bayesian_rating_factor": "0.0",
 
         # rating symbol (black star)
-        "rating_symbol_full": "\xe2\x98\x85",
+        "rating_symbol_full": _config_text(u'\u2605'),
 
         # rating symbol (hollow star)
-        "rating_symbol_blank": "\xe2\x98\x86",
+        "rating_symbol_blank": _config_text(u'\u2606'),
 
-        # probably belongs in memory
-        "repeat": "false",
-
-        # Now deprecated: space-separated headers column
-        #"headers": " ".join(const.DEFAULT_COLUMNS),
-
-        # 2.6: this gets migrated from headers entry in code.
-        # TODO: re-instate columns here in > 2.6 or once most have migrated
-        #"columns": ",".join(const.DEFAULT_COLUMNS),
+        # Comma-separated columns to display in the song list
+        "columns": ",".join(const.DEFAULT_COLUMNS),
 
         # hack to disable hints, see bug #526
         "disable_hints": "false",
@@ -119,49 +202,87 @@ INITIAL = {
         # If set to "true" allow directly deleting files, even on systems that
         # support sending them to the trash.
         "bypass_trash": "false",
+
+        # osx implementation might be buggy so let users disable it
+        "disable_mmkeys": "false",
+
+        # the UI language to use, empty means system default
+        "language": "",
+
+        # the pattern for the main window title
+        "window_title_pattern": "~title~version~~people",
+
+        # the format of the timestamps in DateColumn
+        "datecolumn_timestamp_format": "",
+
+        # scrollbar does not fade out when inactive
+        "scrollbar_always_visible":
+            "true" if (is_osx() or is_windows()) else "false",
     },
+
     "rename": {
         "spaces": "false",
         "windows": "true",
         "ascii": "false",
+        "move_art": "false",
+        "move_art_overwrite": "false",
+        "remove_empty_dirs": "false",
     },
+
     "tagsfrompath": {
         "underscores": "false",
         "titlecase": "false",
         "split": "false",
         "add": "false",
     },
+
     "plugins": {
         # newline-separated plugin IDs
         "active_plugins": "\n".join(AUTO_ENABLED_PLUGINS),
+
         # Issue 1231: Maximum number of SongsMenu plugins to run at once
         "default_max_plugin_invocations": 30,
     },
+
     "editing": {
-        "split_on": "/ & ,", # words to split on
-        "id3encoding": "", # ID3 encodings to try
+        # characters to split tags on
+        "split_on": "/ & ,",
+
+        # ID3 encodings to try
+        "id3encoding": "",
+
         "human_title_case": "true",
         "save_to_songs": "true",
         "save_email": const.EMAIL,
-        "alltags": "true", # show all tags, or just "human-readable" ones
+
+        # show all tags, or just "human-readable" ones
+        "alltags": "true",
+
         # Skip dialog to save or revert changes
         "auto_save_changes": "false",
-        "default_tags": "", # e.g. "title,artist"
+
+        # e.g. "title,artist"
+        "default_tags": "",
     },
+
     "albumart": {
-        "round": "true", # use rounded corners for artwork thumbnails
         "prefer_embedded": "false",
         "force_filename": "false",
         "filename": "folder.jpg",
+        "search_filenames": "cover.jpg,folder.jpg,.folder.jpg",
+    },
+
+    "display": {
+        "duration_format": "standard"
     }
 }
 
-
 # global instance
 _config = Config(version=0)
 
 options = _config.options
 get = _config.get
+gettext = _config.gettext
 getboolean = _config.getboolean
 getint = _config.getint
 getfloat = _config.getfloat
@@ -170,12 +291,15 @@ setstringlist = _config.setstringlist
 getlist = _config.getlist
 setlist = _config.setlist
 set = _config.set
+settext = _config.settext
 write = _config.write
 reset = _config.reset
 add_section = _config.add_section
 has_option = _config.has_option
 remove_option = _config.remove_option
 register_upgrade_function = _config.register_upgrade_function
+getbytes = _config.getbytes
+setbytes = _config.setbytes
 
 _filename = None
 """The filename last used for loading"""
@@ -185,9 +309,9 @@ def init_defaults():
     """Fills in the defaults, so they are guaranteed to be available"""
 
     _config.defaults.clear()
-    for section, values in INITIAL.iteritems():
+    for section, values in iteritems(INITIAL):
         _config.defaults.add_section(section)
-        for key, value in values.iteritems():
+        for key, value in iteritems(values):
             _config.defaults.set(section, key, value)
 
 
@@ -195,7 +319,7 @@ def init(filename=None):
     global _filename
 
     if not _config.is_empty():
-        raise ValueError("config initialized twice without quitting")
+        _config.clear()
 
     _filename = filename
 
@@ -246,6 +370,7 @@ class RatingsPrefs(object):
     """
     Models Ratings settings as configured by the user, with caching.
     """
+
     def __init__(self):
         self.__number = self.__default = None
         self.__full_symbol = self.__blank_symbol = None
@@ -311,14 +436,38 @@ class RatingsPrefs(object):
 
     @staticmethod
     def __get_symbol(variant="full"):
-        return get("settings", "rating_symbol_%s" % variant).decode("utf-8")
+        return gettext("settings", "rating_symbol_%s" % variant)
 
 
 class HardCodedRatingsPrefs(RatingsPrefs):
     number = int(INITIAL["settings"]["ratings"])
     default = float(INITIAL["settings"]["default_rating"])
-    blank_symbol = INITIAL["settings"]["rating_symbol_blank"].decode("utf-8")
-    full_symbol = INITIAL["settings"]["rating_symbol_full"].decode("utf-8")
+    blank_symbol = INITIAL["settings"]["rating_symbol_blank"]
+    full_symbol = INITIAL["settings"]["rating_symbol_full"]
+    if PY2:
+        blank_symbol = blank_symbol.decode("utf-8")
+        full_symbol = full_symbol.decode("utf-8")
+
 
 # Need an instance just for imports to work
 RATINGS = RatingsPrefs()
+
+
+@enum
+class DurationFormat(str):
+    NUMERIC, SECONDS = "numeric", "numeric-seconds"
+    STANDARD, FULL = "standard", "text-full"
+
+
+class DurationFormatPref(object):
+    @property
+    def format(self):
+        raw = get("display", "duration_format")
+        return DurationFormat.value_of(raw, DurationFormat.STANDARD)
+
+    @format.setter
+    def format(self, value):
+        set("display", "duration_format", value)
+
+
+DURATION = DurationFormatPref()
