@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from tests import TestCase
 from .helper import realized
@@ -219,7 +220,7 @@ class TPaneConfig(TestCase):
         self.failUnless(p.has_markup)
 
     def test_group(self):
-        p = PaneConfig("a\:b:<title>")
+        p = PaneConfig(r"a\:b:<title>")
         self.failUnlessEqual(p.title, "A:B")
         self.failUnlessEqual(set(p.format_display(ALBUM).split(", ")),
                              {"one", "two", "three", "four", "xxx"})
