@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from tests import TestCase, get_data_path
 
 import os
-
+import io
+from contextlib import contextmanager
 from senf import fsnative, fsn2text, bytes2fsn, mkstemp, mkdtemp
 
 from quodlibet import config
@@ -15,7 +17,9 @@ from quodlibet.formats import AudioFile, types as format_types, AudioFileError
 from quodlibet.formats._audio import NUMERIC_ZERO_DEFAULT
 from quodlibet.formats import decode_value, MusicFile, FILESYSTEM_TAGS
 from quodlibet.util.tags import _TAGS as TAGS
-from quodlibet.util.path import normalize_path
+from quodlibet.util.path import normalize_path, mkdir, get_home_dir, unquote, \
+                                escape_filename, RootPathFile
+from quodlibet.util.environment import is_windows
 
 from .helper import temp_filename
 
@@ -408,6 +412,196 @@ class TAudioFile(TestCase):
         song["lyricist"] = u"Lyricist"
         self.assertTrue(isinstance(song.lyric_filename, fsnative))
 
+    def lyric_filename_search_test_song(self, pathfile):
+        s = AudioFile()
+        s.sanitize(pathfile)
+        s['artist'] = "SpongeBob SquarePants"
+        s['title'] = "Theme Tune"
+        return s
+
+    @contextmanager
+    def lyric_filename_test_setup(self, no_config=False):
+
+        with temp_filename() as filename:
+            s = self.lyric_filename_search_test_song(filename)
+            root = os.path.dirname(filename)
+
+            if not no_config:
+                config.set("memory", "lyric_filenames",
+                           "<artist>.-.<title>,<artist> - <title>.lyrics_mod")
+            config.set("memory", "lyric_rootpaths", root)
+
+            s.root = root
+            yield s
+
+            if not no_config:
+                self.lyric_filename_search_clean_config()
+
+    def lyric_filename_search_clean_config(self):
+        """reset config to ensure other tests aren't affected"""
+        config.remove_option("memory", "lyric_rootpaths")
+        config.remove_option("memory", "lyric_filenames")
+
+    def test_lyric_filename_search_builtin_default(self):
+        """test built-in default"""
+        with self.lyric_filename_test_setup(no_config=True) as ts:
+            fp = os.path.join(ts.root, ts["artist"], ts["title"] + ".lyric")
+            p = os.path.dirname(fp)
+            mkdir(p)
+            with io.open(fp, "w", encoding='utf-8') as f:
+                f.write(u"")
+            search = unquote(ts.lyric_filename)
+            os.remove(fp)
+            os.rmdir(p)
+            self.assertEqual(search, fp)
+
+    def test_lyric_filename_search_builtin_default_local_path(self):
+        """test built-in default local path"""
+        with self.lyric_filename_test_setup(no_config=True) as ts:
+            fp = os.path.join(ts.root, ts["artist"] + " - " +
+                                       ts["title"] + ".lyric")
+            with io.open(fp, "w", encoding='utf-8') as f:
+                f.write(u"")
+            search = ts.lyric_filename
+            os.remove(fp)
+            if is_windows():
+                fp = fp.lower()  # account for 'os.path.normcase' santisatation
+                search = search.lower()  # compensate for the above
+            self.assertEqual(search, fp)
+
+    def test_lyric_filename_search_file_not_found(self):
+        """test default file not found fallback"""
+        with self.lyric_filename_test_setup() as ts:
+            fp = os.path.join(ts.root, ts["artist"] + ".-." + ts["title"])
+            search = unquote(ts.lyric_filename)
+            self.assertEqual(search, fp)
+
+    def test_lyric_filename_search_custom_path(self):
+        """test custom lyrics file location / naming"""
+        with self.lyric_filename_test_setup() as ts:
+            fp = os.path.join(ts.root, ts["artist"] + " - " +
+                                       ts["title"] + ".lyric")
+            with io.open(fp, "w", encoding='utf-8') as f:
+                f.write(u"")
+            search = ts.lyric_filename
+            os.remove(fp)
+            self.assertEqual(search, fp)
+
+    def test_lyric_filename_search_order_priority(self):
+        """test custom lyrics order priority"""
+        with self.lyric_filename_test_setup() as ts:
+            root2 = os.path.join(get_home_dir(), ".lyrics") # built-in default
+            fp2 = os.path.join(root2, ts["artist"] + " - " +
+                                      ts["title"] + ".lyric")
+            p2 = os.path.dirname(fp2)
+            mkdir(p2)
+            with io.open(fp2, "w", encoding='utf-8') as f:
+                f.write(u"")
+            fp = os.path.join(ts.root, ts["artist"] + " - " +
+                                       ts["title"] + ".lyric")
+            with io.open(fp, "w", encoding='utf-8') as f:
+                f.write(u"")
+            mkdir(p2)
+            search = ts.lyric_filename
+            os.remove(fp2)
+            os.rmdir(p2)
+            os.remove(fp)
+            self.assertEqual(search, fp)
+
+    def test_lyric_filename_search_modified_extension_fallback(self):
+        """test modified extension fallback search"""
+        with self.lyric_filename_test_setup() as ts:
+            fp = os.path.join(ts.root,
+                              ts["artist"] + " - " + ts["title"] + ".txt")
+            with io.open(fp, "w", encoding='utf-8') as f:
+                f.write(u"")
+            search = ts.lyric_filename
+            os.remove(fp)
+            self.assertEqual(search, fp)
+
+    def test_lyric_filename_search_special_characters(self):
+        """test '<' and/or '>' in name (not parsed (transparent to test))"""
+        with self.lyric_filename_test_setup(no_config=True) as ts:
+
+            path_variants = ['<oldskool>'] \
+                if is_windows() else [r'\<artist\>', r'\<artist>',
+                                      r'<artist\>']
+
+            for path_variant in path_variants:
+                ts['artist'] = path_variant + " SpongeBob SquarePants"
+                parts = [ts.root,
+                         ts["artist"] + " - " + ts["title"] + ".lyric"]
+                rpf = RootPathFile(ts.root, os.path.sep.join(parts))
+                if not rpf.valid:
+                    rpf = RootPathFile(rpf.root, rpf.pathfile_escaped)
+                self.assertTrue(rpf.valid,
+                                "even escaped target file is not valid")
+                with io.open(rpf.pathfile, "w", encoding='utf-8') as f:
+                    f.write(u"")
+                search = ts.lyric_filename
+                os.remove(rpf.pathfile)
+                fp = rpf.pathfile
+                if is_windows():
+                    # account for 'os.path.normcase' santisatation
+                    fp = fp.lower()
+                    search = search.lower() # compensate for the above
+                self.assertEqual(search, fp)
+
+    def test_lyric_filename_search_special_characters_across_path(self):
+        """test '<' and/or '>' in name across path separator (not parsed
+        (transparent to test))"""
+        with self.lyric_filename_test_setup(no_config=True) as ts:
+            # test '<' and '>' in name across path
+            # (not parsed (transparent to test))
+            ts['artist'] = "a < b"
+            ts['title'] = "b > a"
+            parts = [ts.root, ts["artist"], ts["title"] + ".lyric"]
+            rpf = RootPathFile(ts.root, os.path.sep.join(parts))
+            rootp = ts.root
+            rmdirs = []
+            # ensure valid dir existence
+            for p in rpf.end.split(os.path.sep)[:-1]:
+                rootp = os.path.sep.join([ts.root, p])
+                if not RootPathFile(ts.root, rootp).valid:
+                    rootp = os.path.sep.join([ts.root, escape_filename(p)])
+                self.assertTrue(RootPathFile(ts.root, rootp).valid,
+                                "even escaped target dir part is not valid!")
+                if not os.path.exists(rootp):
+                    mkdir(rootp)
+                    rmdirs.append(rootp)
+
+            if not rpf.valid:
+                rpf = RootPathFile(rpf.root, rpf.pathfile_escaped)
+
+            with io.open(rpf.pathfile, "w", encoding='utf-8') as f:
+                f.write(u"")
+            # search for lyric file
+            search = ts.lyric_filename
+            # clean up test lyric file / path
+            os.remove(rpf.pathfile)
+            for p in rmdirs:
+                os.rmdir(p)
+            # test whether the 'found' file is the test lyric file
+            fp = rpf.pathfile
+            if is_windows():
+                fp = fp.lower()  # account for 'os.path.normcase' santisatation
+                search = search.lower()  # compensate for the above
+            self.assertEqual(search, fp)
+
+    def test_lyrics_from_file(self):
+        with temp_filename() as filename:
+            af = AudioFile(artist='Motörhead', title='this: again')
+            af.sanitize(filename)
+            lyrics = "blah!\nblasé 😬\n"
+            lyrics_dir = os.path.dirname(af.lyric_filename)
+            mkdir(lyrics_dir)
+            with io.open(af.lyric_filename, "w", encoding='utf-8') as lf:
+                lf.write(text_type(lyrics))
+            self.failUnlessEqual(af("~lyrics").splitlines(),
+                                 lyrics.splitlines())
+            os.remove(af.lyric_filename)
+            os.rmdir(lyrics_dir)
+
     def test_mountpoint(self):
         song = AudioFile()
         song["~filename"] = fsnative(u"filename")
@@ -432,7 +626,7 @@ class TAudioFile(TestCase):
                        ("performer", "C")])
         self.failUnlessEqual(set(q.list("~performers")), {"A", "B", "C"})
         self.failUnlessEqual(set(q.list("~performers:roles")),
-                             {"A (Vocals)", "B (Guitar)", "C"})
+                             {"A (Vocals)", "B (Guitar)", "C (Performance)"})
 
     def test_performers_multi_value(self):
         q = AudioFile([
@@ -446,12 +640,12 @@ class TAudioFile(TestCase):
 
         self.failUnlessEqual(
             set(q.list("~performer:roles")), {
-                    "A (Guitar, Vocals)",
-                    "C",
-                    "B (Guitar)",
+                    "A (Guitar, Performance, Vocals)",
+                    "C (Performance)",
+                    "B (Guitar, Performance)",
                     "X (Vocals)",
                     "Y (Guitar, Vocals)",
-                    "F",
+                    "F (Performance)",
                 })
 
     def test_people(self):
@@ -460,7 +654,7 @@ class TAudioFile(TestCase):
                        ("albumartist", "B"), ("artist", "C")])
         self.failUnlessEqual(q.list("~people"), ["C", "B", "A"])
         self.failUnlessEqual(q.list("~people:roles"),
-                         ["C", "B (Guitar)", "A (Arrangement, Vocals)"])
+            ["C (Performance)", "B (Guitar)", "A (Arrangement, Vocals)"])
 
     def test_people_mix(self):
         q = AudioFile([
@@ -471,7 +665,7 @@ class TAudioFile(TestCase):
         ])
         self.failUnlessEqual(q.list("~people"), ["A"])
         self.failUnlessEqual(q.list("~people:roles"),
-                             ["A (Arrangement, Arrangement, Foo)"])
+            ["A (Arrangement, Arrangement, Foo, Performance)"])
 
     def test_people_multi_value(self):
         q = AudioFile([
@@ -481,9 +675,9 @@ class TAudioFile(TestCase):
         ])
 
         self.failUnlessEqual(q.list("~people"), ["A", "Y", "X"])
-        self.failUnlessEqual(
-            q.list("~people:roles"),
-            ["A (Arrangement, Foo)", "Y", "X (Arrangement, Foo)"])
+        self.failUnlessEqual(q.list("~people:roles"),
+            ["A (Arrangement, Foo, Performance)", "Y (Performance)",
+             "X (Arrangement, Foo)"])
 
     def test_people_individuals(self):
         q = AudioFile({"artist": "A\nX", "albumartist": "Various Artists"})
@@ -509,7 +703,7 @@ class TAudioFile(TestCase):
         self.failUnlessEqual(q.list("~peoplesort"),
                              ["B, The", "C, The", "A, The"])
         self.failUnlessEqual(q.list("~peoplesort:roles"),
-                             ["B, The (Guitar)", "C, The", "A, The (Vocals)"])
+            ["B, The (Guitar)", "C, The (Performance)", "A, The (Vocals)"])
 
     def test_to_dump(self):
         dump = bar_1_1.to_dump()
@@ -736,6 +930,12 @@ class TAudioFile(TestCase):
             f(bar_1_2)
             f(bar_2_1)
 
+    def test_sort_func_custom_numeric(self):
+        func = AudioFile.sort_by_func("~#year")
+
+        files = [AudioFile({"year": "nope"}), AudioFile({"date": "2038"})]
+        assert sorted(files, key=func) == files
+
     def test_uri(self):
         # On windows where we have unicode paths (windows encoding is utf-16)
         # we need to encode to utf-8 first, then escape.
@@ -789,7 +989,7 @@ class TAudioFormats(TestCase):
             except AudioFileError:
                 pass
 
-    def test_reaload_non_existing(self):
+    def test_reload_non_existing(self):
         for t in format_types:
             if not t.is_file:
                 continue
@@ -833,6 +1033,12 @@ class Treplay_gain(TestCase):
         self.song = AudioFile(self.rg_data)
         self.no_rg_song = AudioFile()
 
+    def test_large(self):
+        rg_data = {"replaygain_track_gain": "9999999 dB"}
+        song = AudioFile(rg_data)
+        assert song.replay_gain(["track"], 0, 0) == 1.0
+        assert song.replay_gain([], 0, 99999999999) == 1.0
+
     def test_no_rg_song(self):
         scale = self.no_rg_song.replay_gain(["track"], 0, -6.0)
         self.failUnlessAlmostEqual(scale, self.minus_6db)
@@ -892,7 +1098,7 @@ class Treplay_gain(TestCase):
             self.song.replay_gain(["album", "track"]), radio_rg)
 
     def test_numeric_rg_tags(self):
-        """"Tests fully-numeric (ie no "db") RG tags.  See Issue 865"""
+        """Tests fully-numeric (ie no "db") RG tags.  See Issue 865"""
         self.failUnless(self.song("replaygain_album_gain"), "-1.00 db")
         for key, exp in self.rg_data.items():
             # Hack the nasties off and produce the "real" expected value
