@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from tests import TestCase, get_data_path
 
@@ -144,6 +145,13 @@ class TID3FileMixin(object):
         else:
             self.KIND(self.filename)
 
+    def test_write_empty_replaygain_track_gain(self):
+        f = self.KIND(self.filename)
+        f["replaygain_track_gain"] = ""
+        f.write()
+        f.reload()
+        assert f.replay_gain(["track"]) == 1.0
+
     def test_TXXX_DATE(self):
         # https://github.com/quodlibet/quodlibet/issues/220
         f = mutagen.File(self.filename)
@@ -279,22 +287,18 @@ class TID3FileMixin(object):
                 msg="Wrong tags: %s" % tags)
         af.clear()
 
-    def test_tlen(self):
+    def test_ignore_tlen(self):
         f = mutagen.File(self.filename)
-        f.tags.add(mutagen.id3.TLEN(encoding=0, text=['20000']))
+        f.tags.delall("TLEN")
         f.save()
-        self.failUnlessEqual(self.KIND(self.filename)("~#length"), 20)
+        length = self.KIND(self.filename)("~#length")
 
-        # ignore <= 0 [issue 222]
-        f = mutagen.File(self.filename)
-        f.tags.add(mutagen.id3.TLEN(encoding=0, text=['0']))
-        f.save()
-        self.failUnless(self.KIND(self.filename)("~#length") > 0)
-
-        # inval
-        f.tags.add(mutagen.id3.TLEN(encoding=0, text=['x']))
-        f.save()
-        self.failUnless(self.KIND(self.filename)("~#length") > 0)
+        for value in ["20000", "0", "x"]:
+            f = mutagen.File(self.filename)
+            f.tags.add(mutagen.id3.TLEN(encoding=0, text=[value]))
+            f.save()
+            self.assertAlmostEqual(
+                self.KIND(self.filename)("~#length"), length, 2)
 
     def test_load_tcon(self):
         # check if the mutagen preprocessing is used
