@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from tests import TestCase, get_data_path
 
@@ -69,18 +70,18 @@ class TAPEv2FileMixin(object):
         self.failUnlessEqual(self.s.get("foo"), None)
         self.s.write()
         m = mutagen.apev2.APEv2(self.f)
-        self.failUnlessEqual("foo" in m, True)
+        self.failUnless("foo" in m)
 
     def test_titlecase(self):
         self.s["isRc"] = "1234"
         self.s["fOoBaR"] = "5678"
         self.s.write()
         self.s.reload()
-        self.failUnlessEqual("isrc" in self.s, True)
-        self.failUnlessEqual("foobar" in self.s, True)
+        self.failUnless("isrc" in self.s)
+        self.failUnless("foobar" in self.s)
         m = mutagen.apev2.APEv2(self.f)
-        self.failUnlessEqual("ISRC" in m, True)
-        self.failUnlessEqual("Foobar" in m, True)
+        self.failUnless("ISRC" in m)
+        self.failUnless("Foobar" in m)
 
     def test_disc_mapping(self):
         m = mutagen.apev2.APEv2(self.f)
