@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from quodlibet.config import RATINGS
 from tests import get_data_path, skipUnless, mkstemp, TestCase
@@ -70,7 +71,7 @@ class TVCFileMixin(object):
         assert self.song("~#channels") == 2
 
     def test_deletes_rating(self):
-        config.set("editing", "save_email", "foo@bar.org")
+        config.set("editing", "save_email", "foo@Bar.org")
         self.song["~#rating"] = 0.2
         self.song.write()
         self.song["~#rating"] = RATINGS.default
@@ -80,7 +81,7 @@ class TVCFileMixin(object):
         self.failUnlessEqual(song("~#rating"), RATINGS.default)
 
     def test_new_email_rating(self):
-        config.set("editing", "save_email", "foo@bar.org")
+        config.set("editing", "save_email", "foo@Bar.org")
         self.song["~#rating"] = 0.2
         self.song.write()
         song = type(self.song)(self.filename)
@@ -91,12 +92,12 @@ class TVCFileMixin(object):
         self.song["~#rating"] = 0.2
         self.song.write()
         song = type(self.song)(self.filename)
-        config.set("editing", "save_email", "foo@bar.org")
+        config.set("editing", "save_email", "foo@Bar.org")
         config.set("editing", "save_email", const.EMAIL)
         self.failUnlessEqual(song["~#rating"], 0.2)
 
     def test_different_email_rating(self):
-        config.set("editing", "save_email", "foo@bar.org")
+        config.set("editing", "save_email", "foo@Bar.org")
         self.song["~#rating"] = 0.2
         self.song.write()
         config.set("editing", "save_email", const.EMAIL)
@@ -104,7 +105,7 @@ class TVCFileMixin(object):
         self.failUnlessEqual(song("~#rating"), RATINGS.default)
 
         song.write()
-        config.set("editing", "save_email", "foo@bar.org")
+        config.set("editing", "save_email", "foo@Bar.org")
         song = type(self.song)(self.filename)
         config.set("editing", "save_email", const.EMAIL)
         self.failUnlessEqual(song["~#rating"], 0.2)
