@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk
 
@@ -487,7 +488,7 @@ class TSongFileLibrary(TSongLibrary):
             filename = self.__get_file()
             ret = self.library.add_filename(filename)
             self.failUnless(ret)
-            self.failUnlessEqual(1, len(self.library))
+            self.failUnlessEqual(len(self.library), 1)
             self.failUnlessEqual(len(self.added), 1)
             ret = self.library.add_filename(filename)
             self.failUnless(ret)
@@ -509,7 +510,7 @@ class TSongFileLibrary(TSongLibrary):
                 ret = self.library.add_filename("")
             self.failIf(ret)
             self.failUnlessEqual(len(self.added), 2)
-            self.failUnlessEqual(2, len(self.library))
+            self.failUnlessEqual(len(self.library), 2)
 
         finally:
             config.quit()
