@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from tests import TestCase
 from .helper import visible
 
 from quodlibet.qltk.entry import ValidatingEntry, UndoEntry, Entry
 from quodlibet.query._query import Query
-from quodlibet.util import gdecode
 from quodlibet.compat import text_type
 import quodlibet.config
 
@@ -60,7 +60,7 @@ class TUndoEntry(TestCase):
         self.entry = UndoEntry()
 
     def __equal(self, value):
-        entry_val = gdecode(self.entry.get_text())
+        entry_val = self.entry.get_text()
         self.failUnlessEqual(value, entry_val)
 
     def __insert(self, text, pos):
