@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import uuid
 import tempfile
@@ -12,10 +13,10 @@ import traceback
 import time
 import logging
 
-from senf import getcwd, fsnative, fsn2bytes, bytes2fsn, mkdtemp
+from senf import getcwd, fsnative, fsn2bytes, bytes2fsn, mkdtemp, environ
 
 from quodlibet import _
-from quodlibet.compat import text_type, PY2
+from quodlibet.compat import text_type
 from quodlibet.config import HardCodedRatingsPrefs, DurationFormat
 from quodlibet import config
 from quodlibet import util
@@ -27,12 +28,10 @@ from quodlibet.util import re_escape
 from quodlibet.util.library import set_scan_dirs, get_scan_dirs
 from quodlibet.util.path import fsn2glib, glib2fsn, \
     parse_xdg_user_dirs, xdg_get_system_data_dirs, escape_filename, \
-    strip_win32_incompat_from_path, xdg_get_cache_home, environ, \
+    strip_win32_incompat_from_path, xdg_get_cache_home, \
     xdg_get_data_home, unexpand, expanduser, xdg_get_user_dirs, \
     xdg_get_config_home, get_temp_cover_file, mkdir, mtime
 from quodlibet.util.string import decode, encode, split_escape, join_escape
-from quodlibet.util.string.splitters import split_people, split_title, \
-    split_album
 
 from . import TestCase, skipIf
 from .helper import capture_output, locale_numeric_conv
@@ -114,6 +113,9 @@ class Tunexpand(TestCase):
         else:
             self.failUnlessEqual(path, "~")
 
+    def test_only_profile_case(self):
+        assert isinstance(unexpand(expanduser(fsnative(u"~"))), fsnative)
+
     def test_base_trailing(self):
         path = unexpand(self.d + os.path.sep)
         self.failUnlessEqual(path, self.u + os.path.sep)
@@ -287,7 +289,7 @@ class Thuman_sort(TestCase):
         self.failUnlessEqual(
             util.human_sort_key(u"  3foo    bar6 42.8"),
             util.human_sort_key(u"3 foo bar6  42.8  "))
-        self.failUnlessEqual(64.0 in util.human_sort_key(u"64. 8"), True)
+        self.failUnless(64.0 in util.human_sort_key(u"64. 8"))
 
 
 class Tformat_time(TestCase):
@@ -406,95 +408,6 @@ class Tformat_size(TestCase):
         })
 
 
-class Tsplit_title(TestCase):
-
-    def test_trailing(self):
-        self.failUnlessEqual(split_title("foo ~"), ("foo ~", []))
-
-    def test_prefixed(self):
-        self.failUnlessEqual(split_title("~foo "), ("~foo ", []))
-
-    def test_prefix_and_trailing(self):
-        self.failUnlessEqual(split_title("~foo ~"), ("~foo ~", []))
-
-    def test_prefix_and_version(self):
-        self.failUnlessEqual(split_title("~foo ~bar~"), ("~foo", ["bar"]))
-
-    def test_simple(self):
-        self.failUnlessEqual(split_title("foo (baz)"), ("foo", ["baz"]))
-
-    def test_two_versions(self):
-        self.failUnlessEqual(
-            split_title("foo [b, c]"), ("foo", ["b", "c"]))
-
-    def test_custom_splitter(self):
-        self.failUnlessEqual(
-            split_title("foo [b c]", " "), ("foo", ["b", "c"]))
-
-
-class Tsplit_album(TestCase):
-    def test_album_looks_like_disc(self):
-        self.failUnlessEqual(
-            split_album("disk 2"), ("disk 2", None))
-
-    def test_basic_disc(self):
-        self.failUnlessEqual(
-            split_album("foo disc 1/2"), ("foo", "1/2"))
-
-    def test_looks_like_disc_but_isnt(self):
-        self.failUnlessEqual(
-            split_album("disc foo disc"), ("disc foo disc", None))
-
-    def test_disc_album_and_disc(self):
-        self.failUnlessEqual(
-            split_album("disc foo disc 1"), ("disc foo", "1"))
-
-    def test_weird_disc(self):
-        self.failUnlessEqual(
-            split_album("foo ~disk 3~"), ("foo", "3"))
-
-    def test_weird_not_disc(self):
-        self.failUnlessEqual(
-            split_album("foo ~crazy 3~"), ("foo ~crazy 3~", None))
-
-
-class Tsplit_people(TestCase):
-
-    def test_parened_person(self):
-        self.failUnlessEqual(split_people("foo (bar)"), ("foo", ["bar"]))
-
-    def test_with_person(self):
-        self.failUnlessEqual(
-            split_people("foo (With bar)"), ("foo", ["bar"]))
-
-    def test_with_with_person(self):
-        self.failUnlessEqual(
-            split_people("foo (with with bar)"), ("foo", ["with bar"]))
-
-    def test_featuring_two_people(self):
-        self.failUnlessEqual(
-            split_people("foo featuring bar, qx"), ("foo", ["bar", "qx"]))
-
-    def test_featuring_person_bracketed(self):
-        self.failUnlessEqual(
-            split_people("foo (Ft. bar)"), ("foo", ["bar"]))
-        self.failUnlessEqual(
-            split_people("foo(feat barman)"), ("foo", ["barman"]))
-
-    def test_originally_by(self):
-        self.failUnlessEqual(
-            split_people("title (originally by artist)"),
-            ("title", ["artist"]))
-        self.failUnlessEqual(
-            split_people("title [originally by artist & artist2]"),
-            ("title", ["artist", "artist2"]))
-
-    def test_cover(self):
-        self.failUnlessEqual(
-            split_people("Pyscho Killer [Talking Heads Cover]"),
-            ("Pyscho Killer", ["Talking Heads"]))
-
-
 class Ttag(TestCase):
     def test_empty(self):
         self.failUnlessEqual(util.tag(""), "Invalid tag")
@@ -576,7 +489,7 @@ class Tpattern(TestCase):
                              "Year - Album")
 
     def test_escape(self):
-        self.failUnlessEqual(util.pattern("\<i\><&>\</i\>", esc=True),
+        self.failUnlessEqual(util.pattern(r"\<i\><&>\</i\>", esc=True),
                             "<i>&amp;</i>")
 
     def test_invalid(self):
@@ -584,7 +497,7 @@ class Tpattern(TestCase):
         util.pattern("<d\\")
 
     def test_complex_condition(self):
-        self.assertEqual(util.pattern("<#(bitrate \> 150)|HQ|LQ>"), "LQ")
+        self.assertEqual(util.pattern(r"<#(bitrate \> 150)|HQ|LQ>"), "LQ")
 
     def test_escape_condition(self):
         self.assertEqual(
@@ -773,6 +686,14 @@ class TNormalizePath(TestCase):
         finally:
             os.rmdir(name)
 
+    def test_types(self):
+        from quodlibet.util.path import normalize_path
+
+        assert isinstance(normalize_path(fsnative(u"foo"), False), fsnative)
+        assert isinstance(normalize_path("foo", False), fsnative)
+        assert isinstance(normalize_path(fsnative(u"foo"), True), fsnative)
+        assert isinstance(normalize_path("foo", True), fsnative)
+
     def test_canonicalise(self):
         from quodlibet.util.path import normalize_path as norm
 
@@ -1167,22 +1088,13 @@ class Treraise(TestCase):
 class Tenviron(TestCase):
 
     def test_main(self):
-        for v in util.environ.values():
+        for v in environ.values():
             if os.name == "nt":
                 self.assertTrue(isinstance(v, text_type))
             else:
                 self.assertTrue(isinstance(v, str))
 
 
-class Tgdecode(TestCase):
-
-    def test_main(self):
-        if PY2:
-            self.assertTrue(isinstance(util.gdecode(b"foo"), text_type))
-        else:
-            self.assertTrue(isinstance(util.gdecode(u"foo"), text_type))
-
-
 class Tget_module_dir(TestCase):
 
     def test_self(self):
